package SPVM::R::NDArray::FloatComplex;



1;

=head1 Name

SPVM::R::NDArray::FloatComplex - Short Description

=head1 Description

The R::NDArray::FloatComplex class in L<SPVM> has methods to do someting.

=head1 Usage

  use R::NDArray::FloatComplex;

=head1 Details



=head1 Super Class

L<R::NDArray|SPVM::R::NDArray>

=head1 Class Methods



=head1 Instance Methods



=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

